@@ -3,7 +3,7 @@
 # addqtl.R
 #
 # copyright (c) 2007-2011, Karl W. Broman
-# last modified Feb, 2011
+# last modified May, 2011
 # first written Nov, 2007
 #
 #     This program is free software; you can redistribute it and/or
@@ -47,7 +47,7 @@ function(cross, pheno.col=1, qtl, covar=NULL, formula,
 
   if(!is.null(covar) && !is.data.frame(covar)) {
     if(is.matrix(covar) && is.numeric(covar)) 
-      covar <- as.data.frame(covar)
+      covar <- as.data.frame(covar, stringsAsFactors=TRUE)
     else stop("covar should be a data.frame")
   }
 
@@ -117,7 +117,7 @@ function(cross, pheno.col=1, qtl, covar=NULL, formula,
 
   # check phenotypes and covariates; drop ind'ls with missing values
   if(!is.null(covar)) phcovar <- cbind(pheno, covar)
-  else phcovar <- as.data.frame(pheno)
+  else phcovar <- as.data.frame(pheno, stringsAsFactors=TRUE)
   if(any(is.na(phcovar))) {
     if(ncol(phcovar)==1) hasmissing <- is.na(phcovar)
     else hasmissing <- apply(phcovar, 1, function(a) any(is.na(a)))
@@ -231,7 +231,7 @@ function(cross, pheno.col=1, qtl, covar=NULL, formula,
     results[k,7] <- pf(results[k,5], results[k,1], thefit1$result.full[3,1], lower.tail=FALSE)
   }
                     
-  results <- as.data.frame(results)
+  results <- as.data.frame(results, stringsAsFactors=TRUE)
   class(results) <- c("addint", "data.frame")
   attr(results, "method") <- method
   attr(results, "model") <- model
@@ -247,8 +247,10 @@ function(x, ...)
 {
   meth <- attr(x, "method")
   mod <- attr(x, "model")
+  simp <- attr(x, "simple")
   if(is.null(mod)) mod <- "normal"
   if(is.null(meth)) meth <- "unknown"
+  if(mod=="binary" || simp) attr(x, "pvalues") <- FALSE
   if(meth=="imp") meth <- "multiple imputation"
   else if(meth=="hk") meth <- "Haley-Knott regression"
   cat("Method:", meth, "\n")
@@ -264,9 +266,10 @@ function(x, ...)
   pval <- attr(x, "pvalues")
   if(!is.null(pval) && !pval)
     x <- x[,-ncol(x)+(0:1)]
-  if(mod == "binary" | attr(x, "simple")) x <- x[,-c(2,5,7), drop=FALSE]
 
-  printCoefmat(x, digits=4, cs.ind=1, P.values=TRUE, has.Pvalue=TRUE)
+  if(mod == "binary" || simp) x <- x[,c(1,3,4), drop=FALSE]
+
+  printCoefmat(x, digits=4, cs.ind=1, P.values=pval, has.Pvalue=pval)
     
   cat("\n")
 }
@@ -305,7 +308,7 @@ function(cross, chr, pheno.col=1, qtl, covar=NULL, formula,
 
   if(!is.null(covar) && !is.data.frame(covar)) {
     if(is.matrix(covar) && is.numeric(covar)) 
-      covar <- as.data.frame(covar)
+      covar <- as.data.frame(covar, stringsAsFactors=TRUE)
     else stop("covar should be a data.frame")
   }
 
@@ -480,7 +483,7 @@ function(cross, chr, pheno.col=1, qtl, covar=NULL, formula,
 
   # check phenotypes and covariates; drop ind'ls with missing values
   if(!is.null(covar)) phcovar <- cbind(pheno, covar)
-  else phcovar <- as.data.frame(pheno)
+  else phcovar <- as.data.frame(pheno, stringsAsFactors=TRUE)
   if(any(is.na(phcovar))) {
     if(ncol(phcovar)==1) hasmissing <- is.na(phcovar)
     else hasmissing <- apply(phcovar, 1, function(a) any(is.na(a)))
@@ -566,7 +569,7 @@ function(cross, chr, pheno.col=1, qtl, covar=NULL, formula,
     if(length(o) > 0) # inter-marker locations cited as "c*.loc*"
       w[o] <- paste("c",i,".",w[o],sep="")
     
-    z <- data.frame(lod=as.numeric(sqout)-lod0)
+    z <- data.frame(lod=as.numeric(sqout)-lod0, stringsAsFactors=TRUE)
     z <- cbind(chr=rep(i,length(map)),
                pos=as.numeric(map), z)
     rownames(z) <- w
@@ -617,7 +620,7 @@ function(cross, chr, pheno.col=1, qtl, covar=NULL, formula,
 
   if(!is.null(covar) && !is.data.frame(covar)) {
     if(is.matrix(covar) && is.numeric(covar)) 
-      covar <- as.data.frame(covar)
+      covar <- as.data.frame(covar, stringsAsFactors=TRUE)
     else stop("covar should be a data.frame")
   }
 
@@ -837,7 +840,7 @@ function(cross, chr, pheno.col=1, qtl, covar=NULL, formula,
 
   # check phenotypes and covariates; drop ind'ls with missing values
   if(!is.null(covar)) phcovar <- cbind(pheno, covar)
-  else phcovar <- as.data.frame(pheno)
+  else phcovar <- as.data.frame(pheno, stringsAsFactors=TRUE)
   if(any(is.na(phcovar))) {
     if(ncol(phcovar)==1) hasmissing <- is.na(phcovar)
     else hasmissing <- apply(phcovar, 1, function(a) any(is.na(a)))
@@ -906,7 +909,7 @@ function(cross, chr, pheno.col=1, qtl, covar=NULL, formula,
     if(length(o) > 0) # inter-marker locations cited as "c*.loc*"
       w[o] <- paste("c",ci,".",w[o],sep="")
     map <- cbind(chr=rep(ci,length(map)),
-                 pos=as.data.frame(map) )
+                 pos=as.data.frame(map, stringsAsFactors=TRUE) )
     rownames(map) <- w 
     
     if(method=="imp")
@@ -1159,7 +1162,7 @@ function(cross, pheno.col=1, qtl, covar=NULL, icovar, formula,
     stop("Must include covariate data frame.")
   if(!is.data.frame(covar)) {
     if(is.matrix(covar) && is.numeric(covar)) 
-      covar <- as.data.frame(covar)
+      covar <- as.data.frame(covar, stringsAsFactors=TRUE)
     else stop("covar should be a data.frame")
   }
 
@@ -1345,7 +1348,7 @@ function(cross, pheno.col=1, qtl, covar=NULL, icovar, formula,
     results[k,7] <- pf(results[k,5], results[k,1], thefit1$result.full[3,1], lower.tail=FALSE)
   }
                     
-  results <- as.data.frame(results)
+  results <- as.data.frame(results, stringsAsFactors=TRUE)
   class(results) <- c("addcovarint", "data.frame")
   attr(results, "model") <- model
   attr(results, "method") <- method
@@ -1361,8 +1364,10 @@ function(x, ...)
 {
   meth <- attr(x, "method")
   mod <- attr(x, "model")
+  simp <- attr(x, "simple")
   if(is.null(mod)) mod <- "normal"
   if(is.null(meth)) meth <- "unknown"
+  if(mod=="binary" || simp) attr(x, "pvalues") <- FALSE
   if(meth=="imp") meth <- "multiple imputation"
   else if(meth=="hk") meth <- "Haley-Knott regression"
   cat("Method:", meth, "\n")
@@ -1379,10 +1384,9 @@ function(x, ...)
   if(!is.null(pval) && !pval) 
     x <- x[,-ncol(x)+(0:1)]
 
-  if(mod == "binary" | attr(x, "simple")) x <- x[,-c(2,5,7), drop=FALSE]
+  if(mod == "binary" || simp) x <- x[,c(1,3,4), drop=FALSE]
   
-  printCoefmat(x, digits=4, cs.ind=1, P.values=TRUE, has.Pvalue=TRUE)
-
+  printCoefmat(x, digits=4, cs.ind=1, P.values=pval, has.Pvalue=pval)
     
   cat("\n")
 }
