@@ -8,7 +8,7 @@
 #
 # 
 # first written Februari 2009
-# last modified Feb 2011
+# last modified May 2011
 #
 #     This program is free software; you can redistribute it and/or
 #     modify it under the terms of the GNU General Public License,
@@ -113,7 +113,9 @@ mqmscan <- function(cross,cofactors=NULL,pheno.col=1,model=c("additive","dominan
     if(numcofold!=numcofnew){
       cat("INFO: Removed ",numcofold-numcofnew," cofactors that were close to eachother\n")
     }
-		#CHECK if the phenotype exists
+		#Convert phenotypes from character to numeric
+    pheno.col = stringPhenoToInt(cross,pheno.col)
+    
 		if (length(pheno.col) > 1){
       cross$pheno <- cross$pheno[,pheno.col]   #Scale down the triats
       result <- mqmscanall( cross,cofactors=cofactors,forceML=forceML,model=model,
@@ -340,10 +342,10 @@ mqmscan <- function(cross,cofactors=NULL,pheno.col=1,model=c("additive","dominan
 	qtl <- cbind(qtl,1/(min(info))*(info-min(info))*qtl[,3])
 	colnames(qtl) = c("chr","pos (cM)",paste("LOD",colnames(cross$pheno)[pheno.col]),"info","LOD*info")
 	#Convert to data/frame and scanone object so we can use the standard plotting routines
-	qtl <- as.data.frame(qtl)
+	qtl <- as.data.frame(qtl, stringsAsFactors=TRUE)
 	if(backward && !is.null(qc) && model.present){
 	  attr(qtl,"mqmmodel") <- QTLmodel
-    cimcovar <- as.data.frame(cbind(as.numeric(attr(qtl,"mqmmodel")[[4]]),as.data.frame(attr(qtl,"mqmmodel")[[5]])))
+    cimcovar <- as.data.frame(cbind(as.numeric(attr(qtl,"mqmmodel")[[4]]),as.data.frame(attr(qtl,"mqmmodel")[[5]])), stringsAsFactors=TRUE)
     rownames(cimcovar) <- attr(qtl,"mqmmodel")[[2]]
     colnames(cimcovar) <- c("chr","pos")
     attr(qtl, "marker.covar.pos") <- cimcovar
@@ -361,10 +363,10 @@ mqmscan <- function(cross,cofactors=NULL,pheno.col=1,model=c("additive","dominan
       if(length(to.remove) > 0) qtl <- qtl[-to.remove,]
     }		
     qtl <- addmarkerstointervalmap(cross,qtl)
-  	qtl <- as.data.frame(qtl)
+  	qtl <- as.data.frame(qtl, stringsAsFactors=TRUE)
     if(backward && !is.null(qc) && model.present){
       attr(qtl,"mqmmodel") <- QTLmodel
-      cimcovar <- as.data.frame(cbind(as.numeric(attr(qtl,"mqmmodel")[[4]]),as.data.frame(attr(qtl,"mqmmodel")[[5]])))
+      cimcovar <- as.data.frame(cbind(as.numeric(attr(qtl,"mqmmodel")[[4]]),as.data.frame(attr(qtl,"mqmmodel")[[5]])), stringsAsFactors=TRUE)
       rownames(cimcovar) <- attr(qtl,"mqmmodel")[[2]]
       colnames(cimcovar) <- c("chr","pos")
       attr(qtl, "marker.covar.pos") <- cimcovar
